/* xloadimage.h:
 *
 * jim frost 06.21.89
 *
 * Copyright 1989 Jim Frost.  See included file "copyright.h" for complete
 * copyright information.
 */

#include "copyright.h"
#include <stdio.h>
#include <X11/X.h>
#include <X11/Xlib.h>
#include <X11/Xutil.h>

#include "image.h"
#include "options.h"

#ifdef USE_IMLIB
#include <Imlib.h>
#endif

/* image name and option structure used when processing arguments
 */

typedef struct {
  char         *name;         /* name of image */
  int           atx, aty;     /* location to load image at */
  unsigned int  bright;       /* brightness multiplier */
  unsigned int  center;       /* true if image is to be centered */
  unsigned int  clipx, clipy; /* area of image to be used */
  unsigned int  clipw, cliph;
  unsigned int  colors;       /* max # of colors to use for this image */
  unsigned int  delay;        /* # of seconds delay before auto pic advance */
  unsigned int  dither;       /* true if image is to be dithered */
  float         gamma;        /* display gamma */
  char         *go_to;        /* label to goto */
  unsigned int  gray;         /* true if image is to be grayed */
  unsigned int  merge;        /* true if we should merge onto previous */
  unsigned int  normalize;    /* true if image is to be normalized */
  int           rotate;	      /* # degrees to rotate image */
  unsigned int  smooth;       /* true if image is to be smoothed */
  unsigned int  xzoom, yzoom; /* zoom percentages */
  char         *fg, *bg;      /* foreground/background colors if mono image */
} ImageOptions;

/* This struct holds the X-client side bits for a rendered image.
 */

typedef struct {
  Display  *disp;       /* destination display */
  int       scrn;       /* destination screen */
  int       depth;      /* depth of drawable we want/have */
  Drawable  drawable;   /* drawable to send image to */
  Pixel     foreground; /* foreground and background pixels for mono images */
  Pixel     background;
  Colormap  cmap;       /* colormap used for image */
  GC        gc;         /* cached gc for sending image */
  XImage   *ximage;     /* ximage structure */
} XImageInfo;

#ifndef MAXIMAGES
#define MAXIMAGES BUFSIZ /* max # of images we'll try to load at once */
#endif

/* function declarations
 */

void supportedImageTypes(void); /* imagetypes.c */

char *tail(char *path); /* misc.c */
void memoryExhausted(void);
void internalError(int sig);
void version(void);
void usage(char *name);
void goodImage(Image *image, char *func);
Image *processImage(Display *disp, int scrn, Image *image, ImageOptions *options, unsigned int verbose);
int errorHandler(Display *disp, XErrorEvent *error);

char *expandPath(char *p); /* path.c */
int findImage(char *name, char *fullname);
void listImages(void);
void loadPathsAndExts(void);
void showPath(void);

void sendXImage(XImageInfo *ximageinfo, int src_x, int src_y, int dst_x, int dst_y,
                unsigned int w, unsigned int h); /* send.c */
XImageInfo *imageToXImage(Display *disp, int scrn, Visual *visual, unsigned int ddepth,
                          Image *image, unsigned int private_cmap, unsigned int fit,
                          unsigned int back, unsigned int verbose);
Pixmap      ximageToPixmap(Display *disp, Window parent, XImageInfo *ximageinfo);
void        freeXImage(XImageInfo *ximageinfo);

int   visualClassFromName(char *name); /* window.c */
char *nameOfVisualClass(int class);
void cleanUpWindow(Display *disp);
char imageInWindow(Display *disp, int scrn, Image *image, char *user_geometry,
                   unsigned int fullscreen, unsigned int install, unsigned int  private_cmap,
                   unsigned int fit, unsigned int use_pixmap, unsigned int delay, int visual_class,
                   int argc, char *argv[], unsigned int verbose);
